/*
 *  This program is free software; you can redistribute it and/or modify
 *  it under the terms of the GNU General Public License as published by
 *  the Free Software Foundation; either version 2 of the License, or
 *  (at your option) any later version.
 *
 *  This program is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *  GNU Library General Public License for more details.
 *
 *  You should have received a copy of the GNU General Public License
 *  along with this program; if not, write to the Free Software
 *  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
 */

#include <gnome.h>
#include <stdio.h>
#include <glib.h>
#include <string.h>
#include "interfaccia.h"
#include "callback.h"
#include "files.h"
#include "rubrica.h"
#include "init.h"
#include "util.h"
#include "dialoghi.h"

extern GnomeRubrica *apprub;
extern TipoRubrica *rub;
extern FileRubrica *fr;
extern TelNum *tel_num;
extern Contatore cont;
extern GList *lista;
extern GList *registro;
extern Opzioni *opzioni;
extern gint tot;

GList *weblist=NULL;
GList *maillist=NULL;
GList *tellist=NULL;

/*  item_lista elemento della lista delle schede
    tipo: clist
*/
gchar *item_lista[14] = {
  NULL,       // nome della scheda
  NULL,       // nome individuo
  NULL,       // cognome individuo
  NULL, NULL, NULL, NULL,NULL, NULL,NULL, NULL,NULL, NULL,NULL
};

// extern gchar *item_lista[3];

/* widget definiti all'interno di altri moduli */
/* se non si verificano errori cancellare tutti i commenti */
// extern GtkWidget *notebook;
// extern GtkWidget *form_ok_bt;
// extern GtkWidget *form_cancel_bt;

// extern gchar *web_item;
// extern gchar *mail_item;


/*   Callback
*/

/*   chiude l'applicazioen e ritorna a Gnome
     Da fare: 
     - chiedere conferma all'uscita
     - verificare se ci sono file da salvare
     - chiedere all'utente di salvare gli eventuali file modificati
*/
void chiudi_applicazione(GtkWidget *w, gpointer data)
{
  gtk_main_quit();
  return;
}

void chiudi_form(GtkWidget *w, gpointer data)
{
  GtkWidget *dialog = data;

  gnome_dialog_close(GNOME_DIALOG(dialog));
}

/*  apre un nuovo file, e lo rende disponibile per inserire nuove schede
*/
void on_nuovo_file_cb(void)
{  
  if (opzioni->nuova_rubrica == OP_NUOVA_RUBRICA_STILE_EMACS) {
    fr->modo = NUOVO;
    
    crea_fileselection("Nuovo File Rubrica... ");
  }
  else {
    lista = NULL;
    mostra_lista(lista);

    tot = 0;
    gtk_progress_set_value(GTK_PROGRESS(apprub->progressbar), (gfloat)tot);
    gtk_progress_set_show_text(GTK_PROGRESS(apprub->progressbar), TRUE); 
    
    gtk_clist_clear(GTK_CLIST(apprub->clist_dati));    
    gtk_label_set_text(GTK_LABEL(apprub->label_path_file), "");    
  }
}

/*  apre un file esistente e costruisce la lista delle schede contenute
*/
void on_apri_cb(void)
{  
    fr->modo = APRI;
    
    crea_fileselection("Apri File Rubrica... ");
}

/*  salva il file corrente
*/
void on_salva_cb(void)
{
  fr->modo = SALVA;
  
  if (fr->nomefile == NULL)
    crea_fileselection("Salva Rubrica... ");
  else 
    {
      if ((fr->fp = fopen(fr->nomefile,"a+")) == NULL)
	file_error(fr->nomefile, "scrittura");
      else
	salva_rubrica(fr, lista);   
    }
}

/*  salva il file corrente con il nome ...
*/
void on_salva_con_nome_cb(void)
{
  fr->modo = SALVA_COME;

  crea_fileselection("Salva Rubrica come... ");
}

/*
  ----------------------------------------------------------------
  Taglia, Copia, Incolla, Cancella
    
    - decidere come utilizzare
*/
void on_taglia_cb(void)
{
}


void on_copia_cb(void)
{
}


void on_incolla_cb(void)
{
}

void on_cancella_cb(void)
{
}



/*  Configura l'ambiente Rubrica
*/
void on_preferenze_cb(void)
{
}


/*  scorre la lista delle schede avanti (prec) e indietro (succ)
*/

void on_button_prec_clicked(GtkWidget *w, gpointer data)
{
  gint tot_righe = tot;
  gint cur_riga=0;

  g_print("\nriga: %d", apprub->riga);
}

void on_button_succ_clicked(GtkWidget *w, gpointer data)
{
  return;
}

void trova_scheda_cb(GtkWidget *w, gpointer data)
{
  return;
}

/*  funzioni generali per la determinazione della lista
    attualmente in uso, e per la gestione delle possibili
    situazioni determinate dalle scelte dell'utente
*/  
void selezionata_riga(GtkWidget *cl, gint riga, gint col,
		      GdkEventButton *event, gpointer data)
{
  GtkEntry *en;
  gchar *tipo_lista = data;
  gchar *buffer;
  gchar *tel_buf;
  tipo_telefono tel_tipo;
  gboolean booltel=FALSE;
  GtkWidget *bot;
  GtkWidget *radio;

  /*  DA FARE:
      mantenere il codice attuale per il caso in cui si clicchi una volta
      con il sx, in modo da selezionare una riga della lista

      se si clicca con il dx, aprire un menu shell con le voci
      - modifica
      - cancella
      - sposta
      - ?????? ecc
  */ 
  if (strcmp(tipo_lista, "web") == 0) {
    en = (GtkEntry *) apprub->web;
    bot = (GtkWidget*) leggi_registro("web canc");
  }
  if (strcmp(tipo_lista, "mail") == 0) {
    en = (GtkEntry *) apprub->mail;
    bot = (GtkWidget*) leggi_registro("mail canc");
  }
  if (strcmp(tipo_lista, "tel") == 0) {
    en = (GtkEntry *) apprub->tel;
    bot = (GtkWidget*) leggi_registro("tel canc");
    booltel = TRUE;
  }

  apprub->riga = (gint) riga;
  apprub->colonna = (gint) col;  
  radio = apprub->radio_casa;        /* default */

  gtk_widget_set_sensitive(bot, TRUE);

  gtk_clist_get_text(GTK_CLIST(cl), riga, 0, &buffer);
 
 if (booltel) {
    gtk_clist_get_text(GTK_CLIST(cl), riga, 1, &tel_buf);
    tel_tipo = determina_tipo_telefono(tel_buf);

    switch (tel_tipo) 
      {
      case 0:
	gtk_toggle_button_set_active(GTK_TOGGLE_BUTTON(radio), TRUE);
	break;
      case 1:
	radio = apprub->radio_work;
	gtk_toggle_button_set_active(GTK_TOGGLE_BUTTON(radio), TRUE);
	break;
      case 2:
	radio = apprub->radio_fax;
	gtk_toggle_button_set_active(GTK_TOGGLE_BUTTON(radio), TRUE);
	break;
      case 3:
	radio = apprub->radio_cell;
	gtk_toggle_button_set_active(GTK_TOGGLE_BUTTON(radio), TRUE);
	break;	  
      default:
	break;
      }
  }
  gtk_entry_set_text(en, buffer);

  gtk_signal_connect(GTK_OBJECT(en), "changed", 
		     GTK_SIGNAL_FUNC(entry_modificata), data ); 

  gtk_signal_connect(GTK_OBJECT(radio), "toggle", 
		     GTK_SIGNAL_FUNC(radio_modificati), &tel_tipo); 
}


void web_add_clicked(GtkWidget *w, gpointer data)
{
  GtkWidget *entry = apprub->web;
  GtkCList *cweb_list = (GtkCList*) apprub->web_list;
  gchar *buffer[1];
  gint n;

  if((n = sensibilizza_bottoni("web edit", "web canc", FALSE)) == -1)
    return;

  buffer[0] = gtk_entry_get_text(GTK_ENTRY(entry));
  g_print("\n%s\n",buffer[0]);
  gtk_clist_append(cweb_list,buffer);
  cont.web++;
  gtk_entry_set_text(GTK_ENTRY(entry),"");
}


void web_edit_clicked(void)
{
  gchar *buffer;
  gint n;

  if((n = sensibilizza_bottoni("web edit", "web canc", FALSE)) == -1)
    return;

  buffer = gtk_entry_get_text(GTK_ENTRY(apprub->web));
  gtk_clist_set_text(GTK_CLIST(apprub->web_list), apprub->riga, 0, buffer);
  gtk_entry_set_text(GTK_ENTRY(apprub->web),"");

  gtk_clist_unselect_row(GTK_CLIST(apprub->web_list), apprub->riga, 0);
}

void web_canc_clicked(void)
{  
  gint n;

  if((n = sensibilizza_bottoni("web edit", "web canc", FALSE)) == -1)
    return;

  gtk_clist_remove(GTK_CLIST(apprub->web_list), apprub->riga);
  gtk_clist_unselect_row(GTK_CLIST(apprub->web_list), apprub->riga, 0);

  cont.web--;
}

void mail_add_clicked(GtkWidget *w, gpointer data)
{
  GtkWidget *entry = apprub->mail;
  GtkCList *cmail_list = (GtkCList*) apprub->mail_list;
  gchar *buffer[1];
  gint n;

  if((n = sensibilizza_bottoni("mail edit", "mail canc", FALSE)) == -1)
    return;

  buffer[0] = gtk_entry_get_text(GTK_ENTRY(entry));
  gtk_clist_append(cmail_list,buffer);
  cont.mail++;
  gtk_entry_set_text(GTK_ENTRY(entry),"");
}

void mail_edit_clicked(void)
{  
  gchar *buffer;
  gint n;

  if((n = sensibilizza_bottoni("mail edit", "mail canc", FALSE)) == -1)
    return;

  buffer = gtk_entry_get_text(GTK_ENTRY(apprub->mail));
  gtk_clist_set_text(GTK_CLIST(apprub->mail_list), apprub->riga, 0, buffer);
  gtk_entry_set_text(GTK_ENTRY(apprub->mail),"");

  gtk_clist_unselect_row(GTK_CLIST(apprub->mail_list), apprub->riga, 0);
}

void mail_canc_clicked(void)
{  
  gint n;

  if((n = sensibilizza_bottoni("mail edit", "mail canc", FALSE)) == -1)
    return;

  gtk_clist_remove(GTK_CLIST(apprub->mail_list), apprub->riga);
  gtk_clist_unselect_row(GTK_CLIST(apprub->mail_list), apprub->riga, 0);

  cont.mail--;
}

void tel_add_clicked(GtkWidget *w, gpointer data)
{
  GtkWidget *entry = apprub->tel;
  GtkCList *ctel_list = (GtkCList*) apprub->tel_clista;
  gchar *buffer[2];
  gint tel = tel_num->tipo;

  buffer[0] = gtk_entry_get_text(GTK_ENTRY(entry));

  switch(tel)
    {
    case 0:
      buffer[1] = strdup("Telefono Casa");
      break;
    case 1:
      buffer[1] = strdup("Telefono Ufficio");
      break;
    case 2:
      buffer[1] = strdup("Telefono Fax");
      break;
    case 3:
      buffer[1] = strdup("Telefono Cellulare");
      break;
    default:
      break;
    }

  gtk_clist_append(ctel_list, buffer);
  cont.tel++;
  gtk_entry_set_text(GTK_ENTRY(entry),"");
  gtk_toggle_button_set_active(GTK_TOGGLE_BUTTON(apprub->radio_casa), TRUE);
}

void tel_edit_clicked(void)
{
  gchar *buffer[2];
  gint n;

  /* desensibilizzo i bottoni 
     (applico le modifiche e non sono pi necessari) */
  if((n = sensibilizza_bottoni("tel edit", "tel canc", FALSE)) == -1)
    return;

  buffer[0] = gtk_entry_get_text(GTK_ENTRY(apprub->tel));
  gtk_clist_set_text(GTK_CLIST(apprub->tel_clista),apprub->riga, 0, buffer[0]);
  gtk_entry_set_text(GTK_ENTRY(apprub->tel),"");
  
  if ( (GTK_TOGGLE_BUTTON(apprub->radio_casa)->active) )
    buffer[1] = "Telefono Casa";
  if (GTK_TOGGLE_BUTTON(apprub->radio_work)->active)
    buffer[1] = "Telefono Ufficio";
  if (GTK_TOGGLE_BUTTON(apprub->radio_fax)->active)
    buffer[1] = "Telefono Fax";
  if (GTK_TOGGLE_BUTTON(apprub->radio_cell)->active)
    buffer[1] = "Telefono Cellulare";
  gtk_clist_set_text(GTK_CLIST(apprub->tel_clista),apprub->riga, 1, buffer[1]);
  

  gtk_clist_unselect_row(GTK_CLIST(apprub->tel_clista), apprub->riga, 0);
}

void tel_canc_clicked(void)
{  
  gint n;

  if((n = sensibilizza_bottoni("tel edit", "tel canc", FALSE)) == -1)
    return;

  gtk_clist_remove(GTK_CLIST(apprub->tel_clista), apprub->riga);
  gtk_clist_unselect_row(GTK_CLIST(apprub->tel_clista), apprub->riga, 0);

  cont.tel--;
}

/*  cliccato il bottone della form:
    - ok         
    - applica
    - cancella
    il bottone applica, applica i cambiamenti effettuati
    il bottone ok, applica i cambiamenti effettuati e chiude la form
    il bottone cancella distrugge la form
    ok richiama applica e poi nasconde/distrugge il form
    annulla distrugge il form
    ok e annulla richiamano f. callback di gtk
*/ 


/*  aggiunge la scheda alla lista
*/ 
void aggiungi_scheda_cb(void)
{
  TipoRubrica *tmp;
  GtkWidget *notebook;

  tmp = (TipoRubrica *) g_malloc(sizeof(TipoRubrica));
  notebook = leggi_registro("notebook");

  pulisci_entry(apprub);
  gtk_widget_grab_focus(apprub->scheda);
  gtk_notebook_set_page(GTK_NOTEBOOK(notebook), 0);

  gtk_widget_show(apprub->form);
}

void elimina_scheda_cb(void)
{
  /*    seleziono la scheda
  */

  /*    elimino la scheda dalla lista
   */
}

void prima_scheda_cb(void)
{
  /*    visualizza la prima scheda della lista
  */
}

void ultima_scheda_cb(void)
{
  /*    visualizza l'ultima scheda della lista
   */
}

void modifica_scheda_cb(void)
{

  if (apprub->nominativo_selezionato == FALSE) {
    modifica_error();

    return;
  }
  /*     selezionata una scheda, richiama il form e 
	 consente la modificazione dei campi
  */

  /*     reinserisce nella lista la scheda modificata
  */
}
tipo_telefono radio_click(GtkWidget *radio, TelNum *dato)
{
  if ( (GTK_TOGGLE_BUTTON(apprub->radio_casa)->active) )
       dato->tipo = TELEFONO_CASA;
 
   if (GTK_TOGGLE_BUTTON(apprub->radio_work)->active)
       dato->tipo = TELEFONO_UFFICIO;
     
   if (GTK_TOGGLE_BUTTON(apprub->radio_fax)->active)
       dato->tipo = TELEFONO_FAX;
    
   if (GTK_TOGGLE_BUTTON(apprub->radio_cell)->active)
       dato->tipo = TELEFONO_CELLULARE;

   return (tipo_telefono) dato->tipo;
}


/*    Dati personali 
*/

void prendi_dati_cb(GtkWidget *bottone, GnomeRubrica *apprub)
{
  TipoRubrica *tmp;
  GtkWidget *clista;
  GtkWidget *progressbar;

  clista = apprub->clista;
  progressbar = apprub->progressbar;

  /* acquisizione dei dati  */
  tmp = prendi_dati(apprub);

  if (tmp->nome_scheda != NULL)
    item_lista[0]=g_strdup(tmp->nome_scheda);
  else 
    item_lista[0]=NULL;
  if (tmp->nome != NULL)
    item_lista[1]=g_strdup(tmp->nome);
  else 
    item_lista[1]=NULL;
  if (tmp->cognome != NULL)
    item_lista[2]=g_strdup(tmp->cognome);
  else 
    item_lista[2] = NULL;

  gtk_clist_append((GtkCList*)clista,item_lista);
  tot++;

// gtk_widget_set_sensitive(form_applica_bt,FALSE);
  gtk_progress_set_value(GTK_PROGRESS(progressbar), (gfloat)tot);
  gtk_progress_set_show_text(GTK_PROGRESS(progressbar), TRUE); 

  lista = g_list_append(lista, tmp);
}


TipoRubrica *prendi_dati(GnomeRubrica *apprub)
{
  TipoRubrica *tmp;
  TelNum *tel;
  gchar *pagina_web;
  gchar *email;

  GList *listweb = NULL;
  GList *listmail = NULL;
  GList *listtel = NULL;

  GtkCList *web_clist = (GtkCList*) apprub->web_list;
  GtkCList *mail_clist = (GtkCList*) apprub->mail_list;
  GtkCList *tel_clist = (GtkCList*) apprub->tel_clista;
  GtkEditable *editab = (GtkEditable *) apprub->note;
  
  GtkWidget *check_del;
  GtkWidget *check_edit;

  tmp = (TipoRubrica*) g_malloc (sizeof(TipoRubrica));

  check_del = leggi_registro("check del");
  check_edit = leggi_registro("check edit");

  /*    creo l'elemento dati della lista
  */
  if (gtk_toggle_button_get_active(GTK_TOGGLE_BUTTON(check_del)))
    tmp->cancellabile = TRUE;   //  possibile cancellare l'item
  else
    tmp->cancellabile = FALSE; 
  if (gtk_toggle_button_get_active(GTK_TOGGLE_BUTTON(check_edit)))
    tmp->editabile = TRUE;      //  possibile editare l'item
  else 
    tmp->editabile = FALSE;
  
  tmp->nome_scheda = gtk_entry_get_text(GTK_ENTRY(apprub->scheda));  
  tmp->nome = gtk_entry_get_text(GTK_ENTRY(apprub->nome)); 
  tmp->cognome = gtk_entry_get_text(GTK_ENTRY(apprub->cognome)); 
  tmp->professione = gtk_entry_get_text(GTK_ENTRY(apprub->prof)); 
  tmp->via = gtk_entry_get_text(GTK_ENTRY(apprub->via)); 
  tmp->numero = gtk_entry_get_text(GTK_ENTRY(apprub->num)); 
  tmp->citta = gtk_entry_get_text(GTK_ENTRY(apprub->citta)); 
  tmp->provincia = gtk_entry_get_text(GTK_ENTRY(apprub->prov)); 
  tmp->cap = gtk_entry_get_text(GTK_ENTRY(apprub->cap)); 
  tmp->stato = gtk_entry_get_text(GTK_ENTRY(apprub->stato)); 
  
  cont.web--;
  while(cont.web >= 0)
    {   
      gchar *buffer;

      gtk_clist_get_text(web_clist, cont.web, 0, &pagina_web);
      buffer = strdup(pagina_web);
      listweb = g_list_append(listweb, buffer);
      cont.web--;
    }
  tmp->web = listweb;
  gtk_clist_clear(web_clist);

  cont.mail--;
  while(cont.mail >= 0)
    {
      gchar *buffer;

      gtk_clist_get_text(mail_clist, cont.mail, 0, &email);
      buffer = strdup(email);
      listmail= g_list_append(listmail, buffer); 
      cont.mail--;
    }
  tmp->mail = listmail;
  gtk_clist_clear(mail_clist);

  cont.tel--;
  while(cont.tel >= 0)
    {
      gchar *buffer[2];
      tel = (TelNum*) g_malloc (sizeof(TelNum));

      gtk_clist_get_text(tel_clist, cont.tel, 0, &buffer[0]);
      gtk_clist_get_text(tel_clist, cont.tel, 1, &buffer[1]);

      tel->numero = strdup(buffer[0]);
      tel->tipo = get_tipo_telefono(buffer[1]);

      listtel= g_list_append(listtel, tel);
      cont.tel--;
    }
  tmp->telefono = listtel;
  gtk_clist_clear(tel_clist);
  
  tmp->note = gtk_editable_get_chars(editab, 0, -1);
  tmp->lunghezza = gtk_text_get_length(GTK_TEXT(editab));

  vedi_elemento_debug(tmp);

  return (TipoRubrica*) tmp;
}


void selezione_riga_lista(GtkWidget *cl, gint riga, gint col,
			  GdkEventButton *event, gpointer data)
{
  TipoRubrica *r;
  /*    item_view elemento riassuntivo con i dati 
	da visualizzare nella clist
	
	descrizione elemento      ptr elemento        icona elemento
  */
char *item_view[17][3] = {
  {"Scheda", NULL, NULL },              // n 0       -- nome scheda --
  {"Nome: ", NULL, NULL},              //    1
  {"Cognome: ", NULL, NULL},           //    2
  {"Professione: ", NULL, NULL},       //    3
  {"Via: ", NULL, NULL},               //    4
  {"Numero: ", NULL, NULL},            //    5
  {"Citt: ", NULL, NULL},             //    6
  {"Provincia: ", NULL, NULL},         //    7
  {"Cap: ", NULL, NULL},               //    8
  {"Stato: ", NULL, NULL},             //    9
  {"Sito web: ", NULL, NULL},          //    10
  {"Email: ", NULL, NULL},             //    11
  {"Telefono casa: ", NULL, NULL},     //    12
  {"Telefono ufficio: ", NULL, NULL},  //    13
  {"Telefono Fax: ", NULL, NULL},      //    14
  {"Telefono Cellulare: ", NULL, NULL},//    15
  {"Note: ", NULL, NULL}               //    16
}; 
 
 g_return_if_fail (lista != NULL);

  /*      elemento della rubrica contenuto nella righa-esima posizione
	  selezionato dall'utente tramite la lista delle schede */
  r = (TipoRubrica*) g_list_nth_data(lista, riga);
  
  vedi_elemento_debug(r);

  apprub->riga = riga;
  apprub->colonna = col;
  apprub->nominativo_selezionato = TRUE;

  /*      click -- mostra
	  sono arrivati gli eventi: bottone premuo e rilasciato => 1 click  =
	  il test  sul bottone rilasciato */
  if (event->type == GDK_BUTTON_RELEASE)
    {     
      GList *alias;
      gint i=11;

      /*	item_view[0]..[8] dati personali
      */
      item_view[0][1] = g_strdup(r->nome_scheda);
      item_view[1][1] = g_strdup(r->nome);
      item_view[2][1] = g_strdup(r->cognome);
      item_view[3][1] = g_strdup(r->professione);
      item_view[4][1] = g_strdup(r->via);
      item_view[5][1] = g_strdup(r->numero);
      item_view[6][1] = g_strdup(r->citta);     
      item_view[7][1] = g_strdup(r->provincia);     
      item_view[8][1] = g_strdup(r->cap);     
      item_view[9][1] = g_strdup(r->stato);   

      /*
	item_view[10] per le pagine web
	item_view[11] per gli indirizzi email
	item_view[12] per il telefono di casa
	item_view[13] per il telefono dell'ufficio
	item_view[14] per il fax
	item_view[15] per il telefono cellulare
	item_view[16] per le note
      */
      visualizza_dati(item_view); 

      vedi_elemento_debug(r);

      alias = g_list_first(r->web);
      while (alias != NULL)
	{
	  item_view[10][1] = g_strdup(alias->data); 
	  gtk_clist_insert(GTK_CLIST(apprub->clist_dati),i, item_view[10]);
	  i++;
	  item_view[10][0] = "";
	   
	  alias = alias->next;
	}

      alias = g_list_first(r->mail);
      while (alias != NULL)
	{
	  item_view[11][1] = g_strdup(alias->data); 
	  gtk_clist_insert(GTK_CLIST(apprub->clist_dati),i, item_view[11]);
	  i++;
	  item_view[11][0] = "";

	  alias = alias->next;
	}	  
      
      alias = g_list_first(r->telefono);
      while (alias != NULL)
	{
	  TelNum *tel = (TelNum*) alias->data;
	  
	  switch (tel->tipo)
	    {
	    case TELEFONO_CASA:
	      item_view[12][1]= strdup(tel->numero);
	      gtk_clist_insert(GTK_CLIST(apprub->clist_dati),i, item_view[12]);
	      i++;
	      item_view[12][0] = "";
	      alias = alias->next;
	      break;
	    case TELEFONO_UFFICIO:
	      item_view[13][1]= strdup(tel->numero);
	      gtk_clist_insert(GTK_CLIST(apprub->clist_dati),i, item_view[13]);
	      i++;
	      item_view[13][0] = "";
	      alias = alias->next;
	      break;
	    case TELEFONO_FAX:
	      item_view[14][1]= strdup(tel->numero);
	      gtk_clist_insert(GTK_CLIST(apprub->clist_dati),i, item_view[14]);
	      i++;
	      item_view[14][0] = "";
	      alias = alias->next;
	      break;
	    case TELEFONO_CELLULARE:
	      item_view[15][1]= strdup(tel->numero);
	      gtk_clist_insert(GTK_CLIST(apprub->clist_dati),i, item_view[15]);
	      i++;
	      item_view[15][0] = "";
	      alias = alias->next;
	      break;
	    default:
	      break;
	    }
	}  
      if ( mostra_note(apprub->clist_dati, i, r->note) != 0)
	gtk_clist_insert(GTK_CLIST(apprub->clist_dati), i, item_view[16]);
      
      return;
    }
  
/*doppio click -- modifica */
  if (event->type == GDK_2BUTTON_PRESS)
    {
      g_print("\n\nDoppio click alla riga %d colonna %d",riga,col);
      /* 
	 aprire la form di acquisizione
	 inserire il bottone applica
	 riempire i campi con i valori dell'elemento selezionato
	 spostare il focus su nome scheda
	 
	 alla pressione di applica, modificare i valori e corregere la lista
	 alla pressione di ok, modificare i valori del campo, corregere la
	      lista e chiudere il form
	 alla pressione di annulla, chiudere il form
      */
      
    

      return;
    }

}
