/*
 *  This program is free software; you can redistribute it and/or modify
 *  it under the terms of the GNU General Public License as published by
 *  the Free Software Foundation; either version 2 of the License, or
 *  (at your option) any later version.
 *
 *  This program is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *  GNU Library General Public License for more details.
 *
 *  You should have received a copy of the GNU General Public License
 *  along with this program; if not, write to the Free Software
 *  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
 */

#include <gnome.h>
#include "menu.h"
#include "dialoghi.h"
#include "callback.h"
#include "files.h"

/* 
   definizione della barra dei menu 
*/


static GnomeUIInfo file_menu[] =
{
  GNOMEUIINFO_MENU_NEW_ITEM (N_("_Nuovo File"), N_("Crea una nuova rubrica"),
			     on_nuovo_file_cb, NULL),
  GNOMEUIINFO_MENU_OPEN_ITEM(on_apri_cb, NULL),
  GNOMEUIINFO_MENU_SAVE_ITEM (on_salva_cb, NULL),
  GNOMEUIINFO_MENU_SAVE_AS_ITEM (on_salva_con_nome_cb, NULL),
  GNOMEUIINFO_SEPARATOR,
  GNOMEUIINFO_MENU_EXIT_ITEM (chiudi_applicazione, NULL),
  GNOMEUIINFO_END
};

static GnomeUIInfo modifica_menu[] =
{
  GNOMEUIINFO_MENU_CUT_ITEM (on_taglia_cb, NULL),
  GNOMEUIINFO_MENU_COPY_ITEM (on_copia_cb, NULL),
  GNOMEUIINFO_MENU_PASTE_ITEM (on_incolla_cb, NULL),
  GNOMEUIINFO_MENU_CLEAR_ITEM (on_cancella_cb, NULL),
  GNOMEUIINFO_END
};

static GnomeUIInfo opzioni_menu[] =
{
  GNOMEUIINFO_MENU_PREFERENCES_ITEM (on_preferenze_cb, NULL),
  GNOMEUIINFO_END
};

static GnomeUIInfo aiuto_menu[] =
{
  GNOMEUIINFO_MENU_ABOUT_ITEM (info, NULL),
  {
    GNOME_APP_UI_ITEM, N_("_Dedicato a..."),
    N_("Questo programma  dedicato a:"),
    Dedica, NULL, NULL,
    GNOME_APP_PIXMAP_STOCK, GNOME_STOCK_MENU_ABOUT,
    0, 0, NULL
  },
  {
    GNOME_APP_UI_ITEM, N_("La _Calabria"),
    N_("Visitate la Calabria "),
    Calabria, NULL, NULL,
    GNOME_APP_PIXMAP_STOCK, GNOME_STOCK_MENU_ABOUT,
    0, 0, NULL
  },
  GNOMEUIINFO_END
};

static GnomeUIInfo menubar[] =
{
  GNOMEUIINFO_MENU_FILE_TREE (file_menu),
  GNOMEUIINFO_MENU_EDIT_TREE (modifica_menu),
  GNOMEUIINFO_MENU_SETTINGS_TREE (opzioni_menu),
  GNOMEUIINFO_MENU_HELP_TREE (aiuto_menu),
  GNOMEUIINFO_END
};


/*
  Definizione della Toolbar
*/

static GnomeUIInfo toolbar[] = {
  GNOMEUIINFO_ITEM_STOCK(N_("Nuovo"), N_("Crea una nuova rubrica"),
			 on_nuovo_file_cb, GNOME_STOCK_PIXMAP_NEW),
  GNOMEUIINFO_ITEM_STOCK(N_("Apri"), N_("Apri una rubrica esistente"),
			 on_apri_cb, GNOME_STOCK_PIXMAP_OPEN),
  GNOMEUIINFO_ITEM_STOCK(N_("Salva"), N_("Salva la rubrica corrente"),
			 on_salva_cb, GNOME_STOCK_PIXMAP_SAVE),
  GNOMEUIINFO_SEPARATOR,

  GNOMEUIINFO_ITEM_STOCK(N_("Aggiungi"), 
			 N_("Aggiungi una nuova scheda alla rubrica"),
			 aggiungi_scheda_cb, GNOME_STOCK_PIXMAP_ADD),
  GNOMEUIINFO_ITEM_STOCK(N_("Elimina"), 
			 N_("Elimina la scheda selezionata dalla rubrica"),
			 elimina_scheda_cb, GNOME_STOCK_PIXMAP_REMOVE),
  GNOMEUIINFO_ITEM_STOCK(N_("Modifica"), 
			 N_("Modifica la scheda selezionata"),
			 modifica_scheda_cb, GNOME_STOCK_PIXMAP_CONVERT),
  GNOMEUIINFO_SEPARATOR,

  GNOMEUIINFO_ITEM_STOCK(N_("Inizio"), 
			 N_("Mostra la prima scheda della rubrica"),
			 prima_scheda_cb, GNOME_STOCK_PIXMAP_FIRST),
  
  GNOMEUIINFO_ITEM_STOCK(N_("Fine"), 
			 N_("Mostra l'ultima scheda della rubrica"),
			 ultima_scheda_cb, GNOME_STOCK_PIXMAP_LAST),

  GNOMEUIINFO_ITEM_STOCK(N_("Trova"), 
			 N_("Trova una scheda nella rubrica"),
			 trova_scheda_cb, GNOME_STOCK_PIXMAP_SEARCH),
  GNOMEUIINFO_SEPARATOR,

  GNOMEUIINFO_ITEM_STOCK(N_("Esci"), N_("Esci dal programma"), 
			    chiudi_applicazione, GNOME_STOCK_PIXMAP_EXIT),
  GNOMEUIINFO_END
};


void installa_menu_e_toolbar(GtkWidget *app)
{
GtkWidget *statusbar;
  
  /* creo il menu, la tool bar e la status bar */
  gnome_app_create_menus(GNOME_APP(app), menubar);
  gnome_app_create_toolbar(GNOME_APP(app), toolbar);
  statusbar = gnome_appbar_new(TRUE, TRUE, GNOME_PREFERENCES_USER);
  
  /* collego la statusbar all'applicazione */
  gnome_app_set_statusbar(GNOME_APP(app),statusbar);
  
  /* collego la statusbar con gli hints "suggerimenti" del menu */
  gnome_app_install_menu_hints(GNOME_APP(app), menubar); 
}
